<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
'0_langue' => 'occitan (proven&ccedil;au) [oc_prv]',
'0_liste' => 'lenga.occitana@aprene.org',
'0_mainteneur' => 'Domergue Sumien:&nbsp;lenga.occitana@aprene.org',

// A
'access_interface_graphique' => 'Tornar a l\'interf&agrave;cia grafica completa',
'access_mode_texte' => 'Afichar l\'interf&agrave;cia textuala simplificada',
'admin_debug' => 'desbugatge',
'admin_modifier_article' => 'Modificar aquel article',
'admin_modifier_auteur' => 'Modificar aquel autor',
'admin_modifier_breve' => 'Modificar aquela br&egrave;va',
'admin_modifier_mot' => 'Modificar aqueu mot clau',
'admin_modifier_rubrique' => 'Modificar aquela rubrica',
'admin_recalculer' => 'Tornar calcular la pagina',
'afficher_trad' => 'afficher les traductions', # NEW
'alerte_maj_impossible' => '<b>Al&egrave;rta!</b> Es impossible d\'actualizar la basa SQL v&egrave;rs la version @version@; benl&egrave;u i a un probl&egrave;ma relatiu au drech de modificar la basa de donadas. Vougatz contactar v&ograve;stre aubergador.',
'alerte_modif_info_concourante' => 'ATTENTION : Cette information a &eacute;t&eacute; modifi&eacute;e par ailleurs. La valeur actuelle est&nbsp;:', # NEW
'analyse_xml' => 'Analisi XML',
'annuler' => 'Annuler', # NEW
'antispam_champ_vide' => 'Veuillez laisser ce champ vide&nbsp;:', # NEW
'articles_recents' => 'Leis articles mai recents',
'avis_archive_incorrect' => 'lo fichier archiu es pas un fichier SPIP',
'avis_archive_invalide' => 'lo fichier archiu es pas valid',
'avis_attention' => 'ATENCION!',
'avis_champ_incorrect_type_objet' => 'Nom de camp incorr&egrave;cte @name@ per obj&egrave;cte de tipe @type@',
'avis_colonne_inexistante' => 'La colomna @col@ exist&iacute;s pas',
'avis_echec_syndication_01' => 'La sindicacion s\'es encalada: lo backend indicat es indeschifrable o prepausa ges d\'article.',
'avis_echec_syndication_02' => 'La sindicacion s\'es encalada: impossible d\'accedir au backend d\'aqueu sit.',
'avis_erreur' => 'Error: vejatz &ccedil;ai sota',
'avis_erreur_connexion' => 'Error de connexion',
'avis_erreur_cookie' => 'probl&egrave;ma de cookie',
'avis_erreur_fonction_contexte' => 'Error de programacion. Cau pas apelar aquela foncion dins aqueu cont&egrave;xt.',
'avis_erreur_mysql' => 'Error SQL ',
'avis_erreur_sauvegarde' => 'Error dins la sauvagarda (@type@ @id_objet@)! ',
'avis_erreur_visiteur' => 'Probl&egrave;me d\'acc&egrave;s &agrave; l\'espace priv&eacute;', # NEW

// B
'barre_a_accent_grave' => 'Inserir una A accent gr&egrave;u majuscula',
'barre_aide' => 'Utilizar leis acorchas tipograficas per enriquir v&ograve;stra compaginacion',
'barre_e_accent_aigu' => 'Inserir una E accent agut majuscula',
'barre_eo' => 'Inserir una E dins l\'O',
'barre_eo_maj' => 'Inserir una E dins l\'O majuscula',
'barre_euro' => 'Inserir lo simb&egrave;u de l\'&egrave;uro: &#8364;',
'barre_gras' => 'Metre en {{gras}}',
'barre_guillemets' => 'Enrodar amb de &laquo; verguetas &raquo;',
'barre_guillemets_simples' => 'Enrodar amb de „verguetas“',
'barre_intertitre' => 'Transformar en {{{intert&iacute;tol}}}',
'barre_italic' => 'Metre en {italics}',
'barre_lien' => 'Transformar en [liame ipert&egrave;xt->http://...]',
'barre_lien_input' => 'Vougatz indicar l\'adrei&ccedil;a de v&ograve;stre liame (pod&egrave;tz indicar una adrei&ccedil;a web sota la forma http://www.lomieusit.com o simplament indicar lo num&egrave;ro d\'un article d\'aqueu sit).',
'barre_note' => 'Transformar en [[N&ograve;ta de p&egrave;]]',
'barre_paragraphe' => 'Cr&#233;er un paragraphe', # NEW
'barre_quote' => '<quote>Citar un messatge</quote>',
'bouton_ajouter_document' => 'APONDRE UN DOCUMENT', # MODIF
'bouton_ajouter_image' => 'APONDRE UN IMATGE', # MODIF
'bouton_ajouter_image_document' => 'Ajouter une image ou&nbsp;un&nbsp;document', # NEW
'bouton_changer' => 'Cambiar',
'bouton_chercher' => 'Cercar',
'bouton_choisir' => 'Chausir',
'bouton_download' => 'T&eacute;l&eacute;charger', # NEW
'bouton_enregistrer' => 'Registrar',
'bouton_radio_desactiver_messagerie_interne' => 'Desactivar la messatjari&aacute; int&egrave;rna',
'bouton_radio_envoi_annonces' => 'Mandar leis anoncis editoriaus',
'bouton_radio_non_envoi_annonces' => 'Pas mandar d\'anoncis',
'bouton_radio_non_envoi_liste_nouveautes' => 'Pas mandar la tiera dei novetats',
'bouton_recharger_page' => 'tornar cargar aquela pagina',
'bouton_telecharger' => 'Telecargar',
'bouton_valider' => 'Validar',

// C
'cal_apresmidi' => 'tant&ograve;st',
'cal_jour_entier' => 'jorn entier',
'cal_matin' => 'matin',
'cal_par_jour' => 'calendier per jorn',
'cal_par_mois' => 'calendier per mes',
'cal_par_semaine' => 'calendier per setmana',
'choix_couleur_interface' => 'couleur ', # NEW
'choix_interface' => 'choix  de l\'interface', # NEW
'colonne' => 'Colonne', # NEW
'confirm_changer_statut' => 'Atencion, av&egrave;tz demandat de cambiar l\'estatut d\'aquel element. Desiratz de contunhar? ',
'correcte' => 'corr&egrave;cte', # NEW

// D
'date_aujourdhui' => 'uei',
'date_avant_jc' => 'avans lo Crist',
'date_dans' => 'd\'aqu&iacute; @delai@',
'date_de_mois_1' => '@j@ de genier',
'date_de_mois_10' => '@j@ d\'oct&ograve;bre',
'date_de_mois_11' => '@j@ de novembre',
'date_de_mois_12' => '@j@ de decembre',
'date_de_mois_2' => '@j@ de febrier',
'date_de_mois_3' => '@j@ de mar&ccedil;',
'date_de_mois_4' => '@j@ d\'abriu',
'date_de_mois_5' => '@j@ de mai',
'date_de_mois_6' => '@j@ de junh',
'date_de_mois_7' => '@j@ de julh',
'date_de_mois_8' => '@j@ d\'aost',
'date_de_mois_9' => '@j@ de setembre',
'date_demain' => 'deman',
'date_fmt_heures_minutes' => '@h@h@m@min',
'date_fmt_jour_heure' => '@jour@ a @heure@',
'date_fmt_jour_mois' => '@jourmois@',
'date_fmt_jour_mois_annee' => '@jourmois@ de @annee@',
'date_fmt_mois_annee' => '@nommois@ de @annee@',
'date_fmt_nomjour_date' => 'lo @nomjour@ @date@',
'date_heures' => 'oras',
'date_hier' => 'i&egrave;r',
'date_il_y_a' => 'fa @delai@',
'date_jnum1' => '1r',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'dimenge',
'date_jour_1_abbr' => 'dim.', # NEW
'date_jour_1_initiale' => 'd.', # NEW
'date_jour_2' => 'diluns',
'date_jour_2_abbr' => 'lun.', # NEW
'date_jour_2_initiale' => 'l.', # NEW
'date_jour_3' => 'dimars',
'date_jour_3_abbr' => 'mar.', # NEW
'date_jour_3_initiale' => 'm.', # NEW
'date_jour_4' => 'dim&egrave;cres',
'date_jour_4_abbr' => 'mer.', # NEW
'date_jour_4_initiale' => 'm.', # NEW
'date_jour_5' => 'dij&ograve;us',
'date_jour_5_abbr' => 'jeu.', # NEW
'date_jour_5_initiale' => 'j.', # NEW
'date_jour_6' => 'divendres',
'date_jour_6_abbr' => 'ven.', # NEW
'date_jour_6_initiale' => 'v.', # NEW
'date_jour_7' => 'dissabte',
'date_jour_7_abbr' => 'sam.', # NEW
'date_jour_7_initiale' => 's.', # NEW
'date_jours' => 'jorns',
'date_minutes' => 'minutas',
'date_mois' => 'mes',
'date_mois_1' => 'genier',
'date_mois_10' => 'oct&ograve;bre',
'date_mois_11' => 'novembre',
'date_mois_12' => 'decembre',
'date_mois_2' => 'febrier',
'date_mois_3' => 'mar&ccedil;',
'date_mois_4' => 'abriu',
'date_mois_5' => 'mai',
'date_mois_6' => 'junh',
'date_mois_7' => 'julh',
'date_mois_8' => 'aost',
'date_mois_9' => 'setembre',
'date_saison_1' => 'iv&egrave;rn',
'date_saison_2' => 'prima',
'date_saison_3' => 'estiu',
'date_saison_4' => 'auton',
'date_secondes' => 'secondes', # NEW
'date_semaines' => 'setmana(s)',
'date_un_mois' => 'mois', # NEW
'date_une_heure' => 'heure', # NEW
'date_une_minute' => 'minute', # NEW
'date_une_seconde' => 'seconde', # NEW
'date_une_semaine' => 'semaine', # NEW
'dirs_commencer' => 'per comen&ccedil;ar vertadierament l\'installacion',
'dirs_preliminaire' => 'Preliminar: <b>Reglar lei drechs d\'acc&egrave;s</b>',
'dirs_probleme_droits' => 'Probl&egrave;ma de drechs d\'acc&egrave;s',
'dirs_repertoires_absents' => '<b>S\'es pas trobat lei repert&ograve;ris seguents: <ul>@bad_dirs@.</ul> </b>
  <p>Se p&ograve;t que venga d\'un probl&egrave;ma de majusculas o minusculas mau mesas.
  Verificatz que lei minusculas e majusculas d\'aquelei repert&ograve;ris corresp&ograve;ndan ben amb &ccedil;&ograve; afichat
  &ccedil;ai subre; s\'es pas lo cas, tornatz nommar lei repert&ograve;ris amb v&ograve;stre logiciau FTP en corregissent l\'error.
  <p>Un c&ograve;p qu\'auretz fach aqu&ograve;, poiretz ',
'dirs_repertoires_suivants' => '<b>Lei repert&ograve;ris seguents son pas accessibles en escritura: <ul>@bad_dirs@.</ul> </b>
  <p>Per adobar aqu&ograve;, utilizatz v&ograve;stre client FTP per fin de reglar lei drechs d\'acc&egrave;s de cadun
  d\'aquelei repert&ograve;ris. La guida d\'installacion explica en detalh coma cau procedir.
  </p><p>Tre qu\'auretz facha aquela manipulacion, poiretz </p>',
'double_occurrence' => 'Double occurrence de @balise@', # NEW

// E
'en_cours' => 'en cours', # NEW
'entree_dimensions' => 'Dimensions:',
'entree_titre_document' => 'T&iacute;tol dau document:',
'entree_titre_image' => 'T&iacute;tol de l\'imatge:',
'envoi_via_le_site' => 'Mandad&iacute;s amb lo biais dau sit web',
'erreur' => 'Erreur', # NEW
'erreur_balise_non_fermee' => 'derni&egrave;re balise non referm&eacute;e :', # NEW
'erreur_texte' => 'erreur(s)', # NEW
'etape' => '&Eacute;tape', # NEW

// F
'fichier_introuvable' => 'S\'es pas pogut trobar lo fichier @fichier@.',
'form_auteur_confirmation' => 'Confirmez votre adresse email', # NEW
'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.', # NEW
'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.', # NEW
'form_auteur_mail_confirmation' => 'Bonjour,

Vous avez demand&eacute; &agrave; changer votre adresse email.
Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
l\'adresse ci-dessous (dans le cas contraire, votre demande
sera ignor&eacute;e) :

    @url@
', # NEW
'form_deja_inscrit' => 'Siatz ja inscrich(a).',
'form_email_non_valide' => 'V&ograve;stra adrei&ccedil;a e-mail es pas valida.',
'form_forum_access_refuse' => 'Pod&egrave;tz pus accedir a aqueu sit.',
'form_forum_bonjour' => 'Bonjorn @nom@,',
'form_forum_email_deja_enregistre' => 'Aquela adrei&ccedil;a e-mail ja es registrada, adoncas pod&egrave;tz utilizar v&ograve;stre mot de santa Clara costumier.',
'form_forum_identifiant_mail' => 'Vos av&egrave;m mandat v&ograve;stre identificant nov&egrave;u per e-mail.',
'form_forum_identifiants' => 'Identificants personaus',
'form_forum_indiquer_nom_email' => 'Indicatz aqu&iacute; v&ograve;stre nom e v&ograve;stra adrei&ccedil;a e-mail. V&ograve;stre identificant personau arribar&agrave; l&egrave;u-l&egrave;u, per e-mail.',
'form_forum_login' => 'login:',
'form_forum_message_auto' => '(aqu&ograve;\'s un messatge automatic)',
'form_forum_pass' => 'mot de santa Clara:',
'form_forum_probleme_mail' => 'Probl&egrave;ma d\'e-mail: se p&ograve;t pas mandar l\'identificant.',
'form_forum_voici1' => 'Vaic&iacute; v&ograve;streis identificants per poder participar ai forums
dau sit "@nom_site_spip@" (@adresse_site@):',
'form_forum_voici2' => 'Vaqu&iacute; v&ograve;streis identificants per prepausar d\'articles 
 sus lo sit "@nom_site_spip@" (@adresse_login@):',
'form_indiquer_email' => 'Vougatz indicar v&ograve;stra adrei&ccedil;a e-mail.',
'form_indiquer_nom' => 'Vougatz indicar v&ograve;stre nom.',
'form_indiquer_nom_site' => 'Vougatz indicar lo nom de v&ograve;stre sit.',
'form_pet_adresse_site' => 'Adrei&ccedil;a de v&ograve;stre sit',
'form_pet_aucune_signature' => 'Ges de signatura corresp&ograve;nd a aqueu c&ograve;de...',
'form_pet_confirmation' => 'Vougatz confirmar v&ograve;stra signatura:',
'form_pet_deja_enregistre' => 'Ja aqueu sit es registrat',
'form_pet_deja_signe' => 'Av&egrave;tz ja signat aqueu t&egrave;xt.',
'form_pet_envoi_mail_confirmation' => 'Ara recebretz un e-mail de confirmacion. Per validar v&ograve;stra signatura, cau vesitar l\'adrei&ccedil;a web men&ccedil;onada per aquest corrier.', # MODIF
'form_pet_mail_confirmation' => 'Bonjorn,

av&egrave;tz demandat de signar la peticion:
@titre@.

Av&egrave;tz fornidas leis informacions seguentas :
    Nom: @nom_email@
    Sit: @nom_site@ - @url_site@


IMPORTANT...
Per validar v&ograve;stra signatura, basta de vos connectar a 
 l\'adrei&ccedil;a &ccedil;ai sota (senon s\'escampar&agrave;
 v&ograve;stra demanda): 
    @url@


Grandmerc&eacute; per v&ograve;stra participacion
',
'form_pet_message_commentaire' => 'Un messatge, una remarca?',
'form_pet_nom_site2' => 'Nom de v&ograve;stre sit Web',
'form_pet_probleme_liens' => 'Veuillez reprendre votre message en supprimant les liens hypertexte.', # NEW
'form_pet_probleme_technique' => 'Probl&egrave;ma tecnic, lei signaturas son tempor&agrave;riament arrestadas.',
'form_pet_signature_pasprise' => 'V&ograve;stra signatura es pas presa en c&ograve;mpte.',
'form_pet_signature_validee' => 'V&ograve;stra signatura es validada. Grandmerc&eacute;!',
'form_pet_site_deja_enregistre' => 'Ja aqueu sit es registrat',
'form_pet_url_invalide' => 'L\'URL qu\'av&egrave;tz indicada es pas valida.',
'form_pet_votre_email' => 'V&ograve;stra adrei&ccedil;a e-mail',
'form_pet_votre_nom' => 'V&ograve;stre nom o pseudonim',
'form_pet_votre_site' => 'Se ten&egrave;tz un sit, o pod&egrave;tz marcar &ccedil;ai sota',
'form_prop_confirmer_envoi' => 'Confirmar lo mandad&iacute;s',
'form_prop_description' => 'Descripcion/comentari',
'form_prop_enregistre' => 'V&ograve;stra proposicion es ben registrada, apareisser&agrave; en linha tre que lei responsables dau sit l\'aur&agrave;n validada.',
'form_prop_envoyer' => 'Mandar un messatge',
'form_prop_indiquer_email' => 'Vougatz indicar una adrei&ccedil;a e-mail valida',
'form_prop_indiquer_nom_site' => 'Vougatz indicar lo nom dau sit.',
'form_prop_indiquer_sujet' => 'Vougatz indicar un subj&egrave;cte',
'form_prop_message_envoye' => 'Messatge mandat',
'form_prop_nom_site' => 'Nom dau sit',
'form_prop_non_enregistre' => 'V&ograve;stra proposicion es pas estada registrada.',
'form_prop_sujet' => 'Subj&egrave;cte',
'form_prop_url_site' => 'Adrei&ccedil;a (URL) dau sit',
'forum_acces_refuse' => 'Pod&egrave;tz pus accedir a aquelei forums.',
'forum_attention_dix_caracteres' => '<b>Atencion!</b> v&ograve;stre messatge deu tenir aumens d&egrave;tz caract&egrave;rs.',
'forum_attention_trois_caracteres' => '<b>Atencion!</b> v&ograve;stre t&iacute;tol deu tenir aumens tres caract&egrave;rs.',
'forum_attention_trop_caracteres' => '<b>Attention&nbsp;!</b> votre message est trop long (@compte@ caract&egrave;res)&nbsp;: pour pouvoir &ecirc;tre enregistr&eacute;, il ne doit pas d&eacute;passer @max@ caract&egrave;res.', # NEW
'forum_avez_selectionne' => 'Av&egrave;tz seleccionat:',
'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>aic&iacute;</a> per contunhar.',
'forum_forum' => 'forum',
'forum_info_modere' => 'Aquest forum es moderat a pri&ograve;ri: v&ograve;stra contribucion pareisser&agrave; ren qu\'apr&egrave;s qu\'un administrator dau sit l\'aga validada.',
'forum_lien_hyper' => '<b>Liame ipert&egrave;xt</b> (opcionau)',
'forum_message_definitif' => 'Messatge definitiu: mandar au sit',
'forum_message_trop_long' => 'V&ograve;stre messatge es tr&ograve;p l&ograve;ng. La longor maximala es de 20&nbsp;000 caract&egrave;rs.',
'forum_ne_repondez_pas' => 'Respondatz pas a aquel e-mail mai per lo forum a l\'adrei&ccedil;a seguenta: ',
'forum_non_inscrit' => 'Si&aacute; siatz pas inscrich(a), si&aacute; av&egrave;tz fach una error d\'adrei&ccedil;a o de mot de santa Clara. ',
'forum_page_url' => '(Se v&ograve;stre messatge se refer&iacute;s a un article publicat per lo web, o a una pagina que baile mai d\'informacions, pod&egrave;tz marcar &ccedil;ai sota lo t&iacute;tol de la pagina e son adrei&ccedil;a.)',
'forum_par_auteur' => 'per @auteur@',
'forum_poste_par' => 'Messatge poste@parauteur@ que fa seguida a v&ograve;stre article.',
'forum_probleme_database' => 'Probl&egrave;ma de basa de donadas, v&ograve;stre messatge s\'es pas registrat.',
'forum_qui_etes_vous' => '<b>Quau siatz?</b> (opcionau)',
'forum_texte' => 'T&egrave;xt de v&ograve;stre messatge:',
'forum_titre' => 'T&iacute;tol:',
'forum_titre_erreur' => 'Error...',
'forum_url' => 'URL:',
'forum_valider' => 'Validar aquela chausida',
'forum_voir_avant' => 'Veire lo messatge avans de lo mandar',
'forum_votre_email' => 'V&ograve;stra adrei&ccedil;a e-mail:',
'forum_votre_nom' => 'V&ograve;stre nom (o pseudonim):',
'forum_vous_enregistrer' => 'Per participar a
  aqueu forum, d\'en primier vos cau registrar. Grandmerc&eacute;
  de marcar &ccedil;ai sota l\'identificant personau qu\'av&egrave;tz recebut.
 Se siatz pas registrat/ada, av&egrave;tz de',
'forum_vous_inscrire' => 'vos inscriure.',

// I
'ical_texte_rss_articles' => 'Lo fichier "backend" deis articles d\'aquest sit se tr&ograve;ba a l\'adrei&ccedil;a:',
'ical_texte_rss_articles2' => 'Atanben pod&egrave;tz obtenir de fichiers "backend" per leis articles de cada rubrica dau sit:',
'ical_texte_rss_breves' => 'Existisson mai d\'un fichier contenent lei br&egrave;vas dau sit. En precisant un num&egrave;ro de rubrica,  obtendretz ren que lei br&egrave;vas de la rubrica aquela.',
'icone_a_suivre' => 'De seguir',
'icone_admin_site' => 'Administracion dau sit',
'icone_agenda' => 'Agenda',
'icone_aide_ligne' => 'Ajuda',
'icone_articles' => 'Articles',
'icone_auteurs' => 'Autors',
'icone_breves' => 'Br&egrave;vas',
'icone_brouteur' => 'Navigacion rapida',
'icone_configuration_site' => 'Configuracion',
'icone_configurer_site' => 'Configurar v&ograve;stre sit',
'icone_creer_nouvel_auteur' => 'Crear un autor n&ograve;u ',
'icone_creer_rubrique' => 'Crear una rubrica',
'icone_creer_sous_rubrique' => 'Crear una sosrubrica',
'icone_deconnecter' => 'Se desconnectar',
'icone_discussions' => 'Discussions',
'icone_doc_rubrique' => 'Documents dei rubricas',
'icone_ecrire_article' => 'Escriure un article n&ograve;u',
'icone_edition_site' => 'Edicion',
'icone_forum_administrateur' => 'Forum deis administrators',
'icone_forum_suivi' => 'Seguit dei forums',
'icone_gestion_langues' => 'Gestion dei lengas',
'icone_informations_personnelles' => 'Informacions personalas',
'icone_interface_complet' => 'Interf&agrave;cia completa',
'icone_interface_simple' => 'Interf&agrave;cia simplificada',
'icone_maintenance_site' => 'Mantenen&ccedil;a dau sit',
'icone_messagerie_personnelle' => 'Messatjari&aacute; personala',
'icone_mots_cles' => 'Mots clau',
'icone_nouvelle_breve' => 'Escriure una br&egrave;va n&ograve;va',
'icone_repartition_actuelle' => 'Afichar la reparticion actuala',
'icone_repartition_debut' => 'Afichar la reparticion dempuei la comen&ccedil;an&ccedil;a',
'icone_repartition_visites' => 'Reparticion dei vesitas',
'icone_rubriques' => 'Rubricas',
'icone_sauver_site' => 'Sauvagarda dau sit',
'icone_site_entier' => 'Tot lo sit ',
'icone_sites_references' => 'Sits referenciats',
'icone_statistiques' => 'Estadisticas dau sit',
'icone_statistiques_visites' => 'Estadisticas',
'icone_suivi_activite' => 'Seguir la vida dau sit',
'icone_suivi_actualite' => 'Evolucion dau sit',
'icone_suivi_forums' => 'Seguir/gerir lei forums',
'icone_suivi_pettions' => 'Seguir/gerir lei peticions',
'icone_suivi_revisions' => 'Modificacions deis articles',
'icone_supprimer_document' => 'Suprimir aqueu document',
'icone_supprimer_image' => 'Suprimir aquel imatge',
'icone_supprimer_message' => 'Suprimir aqueu messatge',
'icone_tous_articles' => 'Totei v&ograve;streis articles ',
'icone_tous_auteur' => 'Totei leis autors ',
'icone_valider_message' => 'Validar aqueu messatge',
'icone_visiter_site' => 'Vesitar',
'icone_voir_en_ligne' => 'Veire en linha',
'image_tourner_180' => 'Rotacion 180&deg;',
'image_tourner_droite' => 'Rotacion 90&deg; cap a drecha',
'image_tourner_gauche' => 'Rotacion 90&deg; cap a esquerra',
'img_indisponible' => 'imatge indisponible',
'impossible' => 'impossible',
'info_a_suivre' => 'DE SEGUIR&gt;&gt;',
'info_a_valider' => '[de validar]',
'info_acces_interdit' => 'Acc&egrave;s pro&iuml;bit',
'info_acces_refuse' => 'Acc&egrave;s refusat',
'info_action' => 'Accion: @action@',
'info_administrer_rubriques' => 'Pod&egrave;tz administrar aquela rubrica e sei sosrubricas',
'info_adresse_non_indiquee' => 'Av&egrave;tz pas indicat l\'adrei&ccedil;a de testar!',
'info_aide' => 'AJUDA:',
'info_ajouter_mot' => 'Apondre aqueu mot',
'info_annonce' => 'ANONCI',
'info_annonces_generales' => 'Anoncis generaus:',
'info_article_propose' => 'Article prepausat',
'info_article_publie' => 'Article publicat',
'info_article_redaction' => 'Article en cors de redaccion',
'info_article_refuse' => 'Article refusat',
'info_article_supprime' => 'Article suprimit',
'info_articles' => 'Articles',
'info_articles_a_valider' => 'Los articles de validar',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => 'Articles prepausats',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => 'autor(s)',
'info_authentification_ftp' => 'autentificacion (per FTP).',
'info_bloquer_lien' => 'Blocar aqueu liame',
'info_breves_02' => 'Br&egrave;vas',
'info_breves_2' => 'br&egrave;vas',
'info_breves_nb' => '@nb@ br&egrave;ves', # NEW
'info_breves_un' => '1 br&egrave;ve', # NEW
'info_breves_valider' => 'Br&egrave;vas de validar',
'info_connexion_refusee' => 'Connexion refusada',
'info_contact_developpeur' => 'Vougatz contactar un desvolopaire.',
'info_contenance' => 'Aqueu sit conten:',
'info_contribution' => 'Contribucions de forum',
'info_copyright' => '@spip@ es un logiciau liure distribuit @lien_gpl@.',
'info_copyright_doc' => 'Per mai d\'informacions, veire lo sit <a href="@spipnet@">http://www.spip.net/oc</a>.', # MODIF
'info_copyright_gpl' => 'sota lic&eacute;ncia GPL',
'info_cours_edition' => 'V&ograve;streis articles en cors de redaccion',
'info_creer_repertoire' => 'Vougatz crear un fichier o un repert&ograve;ri nommat',
'info_creer_repertoire_2' => 'dintre lo sosrepert&ograve;ri   <b>@repertoire@</b>, puei:',
'info_creer_vignette' => 'creacion automatica de la vinheta',
'info_deplier' => 'Desplegar',
'info_descriptif_nombre' => 'descriptiu(s):',
'info_description' => 'Descripcion:',
'info_description_2' => 'Descripcion:',
'info_dimension' => 'Dimensions:',
'info_document' => 'Document ',
'info_document_indisponible' => 'Ce document n\'est pas disponible', # NEW
'info_documents' => 'Documents',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'SPIP permet d\'escambiar de messatges e de constituir de forums privats de discussion entre lei participants dau sit. Pod&egrave;tz activar o desactivar aquela foncionalitat.',
'info_ecire_message_prive' => 'Escriure un messatge privat',
'info_email_invalide' => 'Adrei&ccedil;a e-mail invalida',
'info_en_cours_validation' => 'V&ograve;streis articles en cors de redaccion',
'info_en_ligne' => 'Ara en linha:',
'info_envoyer_message_prive' => 'Mandar un messatge privat a aquel autor',
'info_erreur_requete' => 'Error dins la requista',
'info_erreur_squelette2' => 'Ges d\'esqueleta <b>@fichier@</b> es disponibla...',
'info_erreur_systeme' => 'Error sist&egrave;ma (errno @errsys@)',
'info_erreur_systeme2' => 'Lo disc dur es benl&egrave;u plen, o la basa de donadas degalhada. <br />
 <font color=\'red\'>Assajatz de <a href=\'@script@\'>reparar la basa</a>,
 o contactatz v&ograve;stre aubergador.</font>',
'info_fini' => 'Es acabat!',
'info_format_image' => 'Formats d\'imatges que se p&ograve;don utilizar per crear de vinhetas: @gd_formats@.',
'info_format_non_defini' => 'format non definit',
'info_grand_ecran' => 'Ecran grand',
'info_image_aide' => 'AJUDA',
'info_image_process_titre' => 'Met&ograve;de de fabricacion dei vinhetas',
'info_impossible_lire_page' => '<b>Error!</b> Impossible de legir la pagina <tt><html>@test_proxy@</html></tt> a trav&egrave;rs dau proxy <tt>',
'info_inclusion_directe' => 'Inclusion dir&egrave;cta:',
'info_inclusion_vignette' => 'Inclusion de la vinheta:',
'info_installation_systeme_publication' => 'Installacion dau sist&egrave;ma de publicacion...',
'info_installer_documents' => 'Pod&egrave;tz installar automaticament totei lei documents contenguts dins lo repert&ograve;ri @upload@.',
'info_installer_ftp' => 'Coma administrator, pod&egrave;tz installar (per FTP) de fichiers dins lo dorsier @upload@, puei lei seleccionar directament aic&iacute;.',
'info_installer_images' => 'Pod&egrave;tz installar d\'imatges ai formats JPEG, GIF e PNG.',
'info_installer_images_dossier' => 'Installar d\'imatges dins lo dorsier @upload@ per lei poder seleccionar aic&iacute;.',
'info_installer_tous_documents' => 'Installar totei lei documents ',
'info_interface_complete' => 'Interf&agrave;cia completa',
'info_interface_simple' => 'Interf&agrave;cia simplificada',
'info_joindre_document_article' => 'Pod&egrave;tz j&oacute;nher a aquel article de documents de la mena de',
'info_joindre_document_rubrique' => 'Pod&egrave;tz apondre a aquela rubrica de documents de la mena de',
'info_joindre_documents_article' => 'Pod&egrave;tz j&oacute;nher a aquel article de documents de la mena de:',
'info_l_article' => 'l\'article',
'info_la_breve' => 'la br&egrave;va',
'info_la_rubrique' => 'la rubrica',
'info_langue_principale' => 'Lenga majorala dau sit',
'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ pix&egrave;ls',
'info_les_auteurs_1' => 'per @les_auteurs@ ',
'info_logo_format_interdit' => 'Lei l&ograve;gos de formats @formats@ son sols autorizats.',
'info_logo_max_poids' => 'Lei l&ograve;gos an de far mens de @maxi@ (aquest fichier fa @actuel@).',
'info_logo_max_taille' => 'Lei l&ograve;gos an de far mens de @maxi@ (aquest fichier fa @actuel@).',
'info_mail_fournisseur' => 'vos@fornidor.com',
'info_message_2' => 'MESSATGE',
'info_message_supprime' => 'MESSATGE SUPRIMIT',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => 'Data de mesa en linha:',
'info_modification_parametres_securite' => 'modificacions dei param&egrave;tres de seguretat',
'info_mois_courant' => 'Dins lo corrent dau mes:',
'info_mot_cle_ajoute' => 'S\'es apondut lo mot clau seguent a',
'info_multi_herit' => 'Lenga predefinida',
'info_multi_langues_soulignees' => 'Lei <u>lengas solinhadas</u> benef&iacute;cian d\'una revirada de totei lei t&egrave;xts de l\'interf&agrave;cia. Se seleccionatz aquelei lengas, f&ograve;r&ccedil;a elements dau sit public (datas, formularis) se revirar&agrave;n automaticament. Per lei lengas non solinhadas, aqueleis elements apareisser&agrave;n dins la lenga principala dau sit.',
'info_multilinguisme' => 'Multiling&uuml;isme',
'info_nom_non_utilisateurs_connectes' => 'V&ograve;stre nom apareis pas dins la tiera deis utilizaires connectats.',
'info_nom_utilisateurs_connectes' => 'V&ograve;stre nom apareis dins la tiera deis utilizaires connectats.',
'info_nombre_en_ligne' => 'Ara en linha:',
'info_non_resultat' => 'Ges de resultat per "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'Utilizatz pas la messatjari&aacute; int&egrave;rna d\'aqueu sit.',
'info_nouveau_message' => 'AV&Egrave;TZ UN MESSATGE N&Ograve;U',
'info_nouveaux_messages' => 'AV&Egrave;TZ @total_messages@ MESSATGES N&Ograve;US',
'info_numero_abbreviation' => 'N&deg;&nbsp;',
'info_obligatoire' => 'Cette information est obligatoire', # NEW
'info_panne_site_syndique' => 'Sit sindicat en pana',
'info_pense_bete' => 'MEMENTO',
'info_petit_ecran' => 'Ecran pich&ograve;t ',
'info_petition_close' => 'P&eacute;tition close', # NEW
'info_pixels' => 'pix&egrave;ls',
'info_plusieurs_mots_trouves' => 'Mai d\'un mot clau trobat per "@cherche_mot@":',
'info_popularite_5' => 'popularitat:',
'info_portfolio' => 'P&ograve;rtf&ograve;lio',
'info_portfolio_automatique' => 'P&ograve;rtf&ograve;lio automatic:',
'info_premier_resultat' => '[@debut_limit@ primiers resultats de @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ primiers resultats de @total@]',
'info_probleme_grave' => 'probl&egrave;ma de',
'info_propose_1' => '[@nom_site_spip@] Prepausa: @titre@',
'info_propose_2' => 'Article prepausat
---------------',
'info_propose_3' => 'L\'article "@titre@" es prepausat a la publicacion.',
'info_propose_4' => 'Vos convidam a lo venir consultar e a bailar v&ograve;stre vejaire',
'info_propose_5' => 'dins lo forum que li es estacat. Es disponible a l\'adrei&ccedil;a:',
'info_publie_01' => 'L\'article "@titre@" es estat validat per @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] PUBLICA: @titre@',
'info_publie_2' => 'Article publicat
--------------',
'info_rechercher' => 'Cercar',
'info_rechercher_02' => 'Cercar:',
'info_remplacer_vignette' => 'Rempla&ccedil;ar la vinheta predefinida per un l&ograve;go personalizat:',
'info_retablir_lien' => 'Restablir aqueu liame',
'info_retirer_mot' => 'Quitar aqueu mot',
'info_retirer_mots' => 'Quitar totei lei mots ',
'info_rubriques_nb' => '@nb@ rubriques', # NEW
'info_rubriques_un' => '1 rubrique', # NEW
'info_sans_titre_2' => 'sensa t&iacute;tol',
'info_selectionner_fichier' => 'Pod&egrave;tz seleccionar un fichier dau dorsier @upload@',
'info_selectionner_fichier_2' => 'Seleccionar un fichier:',
'info_signature_supprimee' => 'Signature supprim&eacute;e', # NEW
'info_signature_supprimee_erreur' => 'Erreur&nbsp;: ce code de suppression ne correspond a aucune signature', # NEW
'info_site_attente' => 'Sit web en esp&egrave;ra de validacion',
'info_site_reference' => 'Sit referenciat en linha',
'info_site_refuse' => 'Sit web refusat',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'Referenciar un sit',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => 'suprimir la vinheta',
'info_symbole_bleu' => 'Lo simb&egrave;u <b>blau</b> marca un <b>memento</b>: valent a dire un messatge per v&ograve;stre usatge personau.',
'info_symbole_jaune' => 'Lo simb&egrave;u <b>jaune</b> marca un <b>anonci per totei lei redactors </b>: leis administrators lo p&ograve;don modificar, cada redactor lo p&ograve;t veire.',
'info_symbole_vert' => 'Lo simb&egrave;u <b>verd</b> marca lei <b>messatges escambiats amb d\'autreis utilizaires</b> dau sit.',
'info_syndication' => 'sindicacion:',
'info_syndication_articles' => 'article(s)',
'info_telecharger' => 'Telecargar a partir de v&ograve;stre ordenador:',
'info_telecharger_nouveau_logo' => 'Telecargar un l&ograve;go n&ograve;u:',
'info_telecharger_ordinateur' => 'Telecargar a partir de v&ograve;stre ordenador:',
'info_tous_resultats_enregistres' => '[totei lei resultats son registrats]',
'info_tout_afficher' => 'Afichar tot',
'info_travaux_texte' => 'Aqueu sit es pas encara configurat. Tornatz mai tard...',
'info_travaux_titre' => 'Sit en &ograve;bras',
'info_trop_resultat' => 'Tr&ograve;p de resultats per "@cherche_mot@"; vougatz afinar la c&egrave;rca.',
'info_utilisation_messagerie_interne' => 'Utilizatz la messatjari&aacute; int&egrave;rna d\'aqueu sit.',
'info_valider_lien' => 'validar aqueu liame',
'info_verifier_image' => ', vougatz verificar que leis imatges se sigan ben transferits.',
'info_vignette_defaut' => 'Vinheta predefinida',
'info_vignette_personnalisee' => 'Vinheta personalizada',
'info_visite' => 'vesita:',
'info_visites' => 'vesitas:',
'info_vos_rendez_vous' => 'V&ograve;strei rend&egrave;tz-vos venents',
'info_zoom' => 'zoom',
'infos_vos_pense_bete' => 'V&ograve;strei mementos',
'item_breve_proposee' => 'Br&egrave;va prepausada',

// L
'lien_afficher_icones_seuls' => 'Afichar ren que leis ic&ograve;nas ',
'lien_afficher_texte_icones' => 'Afichar leis ic&ograve;nas e lo t&egrave;xt',
'lien_afficher_texte_seul' => 'Afichar ren que lo t&egrave;xt ',
'lien_liberer' => 'liberar',
'lien_liberer_tous' => 'liberar aqueleis articles',
'lien_nouvea_pense_bete' => 'MEMENTO N&Ograve;U',
'lien_nouveau_message' => 'MESSATGE N&Ograve;U',
'lien_nouvelle_annonce' => 'ANONCI NOV&Egrave;U',
'lien_petitions' => 'PETICION',
'lien_popularite' => 'popularitat: @popularite@%',
'lien_racine_site' => 'RAI&Ccedil; DAU SIT',
'lien_reessayer' => 'tornar assajar',
'lien_repondre_message' => 'Resp&ograve;ndre a aqueu messatge',
'lien_supprimer' => 'suprimir',
'lien_tout_afficher' => 'Afichar tot',
'lien_visite_site' => 'vesitar aqueu sit',
'lien_visites' => '@visites@&nbsp;vesitas',
'lien_voir_auteur' => 'Veire aquel autor',
'ligne' => 'Ligne', # NEW
'login' => 'Connexion', # NEW
'login_acces_prive' => 'acc&egrave;s a l\'espaci privat',
'login_autre_identifiant' => 'se connectar amb un autre identificant',
'login_cookie_accepte' => 'Vougatz configurar v&ograve;stre navigador per que leis  acc&egrave;pte (aumens per aqueu sit).',
'login_cookie_oblige' => 'Per vos identificar d\'un biais segur sus aquest sit, vos cau acceptar lei cookies.',
'login_deconnexion_ok' => 'Siatz desconnectat/ada.',
'login_erreur_pass' => 'Error de mot de santa Clara.',
'login_espace_prive' => 'espaci privat',
'login_identifiant_inconnu' => 'L\'identificant &laquo;@login@&raquo; es inconegut.',
'login_login' => 'Login:',
'login_login2' => 'Login (identificant de connexion au sit):',
'login_login_pass_incorrect' => '(Login o mot de santa Clara incorr&egrave;cte.)',
'login_motpasseoublie' => 'mot&nbsp;de&nbsp;santa&nbsp;Clara&nbsp;oblidat?',
'login_non_securise' => 'Atencion, aqueu formulari es pas securizat.
    Se vol&egrave;tz pas que v&ograve;stre mot de santa Clara si&aacute;
   interceptat sus la ret, vougatz activar Javascript 
   dins v&ograve;stre navigador e',
'login_nouvelle_tentative' => 'nov&egrave;l assai',
'login_par_ici' => 'Siatz registrat/ada... per aqu&iacute;...',
'login_pass2' => 'Mot de santa Clara:',
'login_preferez_refuser' => '<b>Se vos agrada mai de refusar lei cookies</b>, un autre met&ograve;de de connexion (mens securizat) es a v&ograve;stra disposicion:',
'login_recharger' => 'tornar cargar aquela pagina',
'login_rester_identifie' => 'Restar identificat/ada quauquei jorns',
'login_retour_public' => 'Tornar au sit public',
'login_retour_site' => 'Tornar au sit public',
'login_retoursitepublic' => 'tornar&nbsp;au&nbsp;sit&nbsp;public',
'login_sans_cookiie' => 'Identificacion sensa cookie',
'login_securise' => 'Login s&eacute;curis&eacute;', # NEW
'login_sinscrire' => 's\'inscriure',
'login_test_navigateur' => 'Assai navigador/tornar&nbsp;connectar',
'login_verifiez_navigateur' => '(pasmens verificatz que v&ograve;stre navigador aga pas servat v&ograve;stre mot de santa Clara en mem&ograve;ria...)',

// M
'masquer_colonne' => 'Masquer cette colonne', # NEW
'masquer_trad' => 'masquer les traductions', # NEW
'module_fichiers_langues' => 'Fichiers de lenga',

// N
'navigateur_pas_redirige' => 'Se v&ograve;stre navigador es pas redirigit, clicatz aic&iacute; per contunhar.',
'numero' => 'Num&eacute;ro', # NEW

// O
'occurence' => 'Occurrence', # NEW
'onglet_affacer_base' => 'Escafar la basa',
'onglet_auteur' => 'L\'autor',
'onglet_contenu_site' => 'Contengut dau sit',
'onglet_evolution_visite_mod' => 'Evolucion',
'onglet_fonctions_avances' => 'Foncions avan&ccedil;adas',
'onglet_informations_personnelles' => 'Informacions personalas',
'onglet_interactivite' => 'Interactivitat',
'onglet_messagerie' => 'Messatjari&aacute;',
'onglet_messages_internes' => 'Messatges int&egrave;rnes',
'onglet_messages_publics' => 'Messatges publics',
'onglet_messages_vide' => 'Messatges sens t&egrave;xt',
'onglet_origine_visites' => 'Origina de las vesitas',
'onglet_repartition_debut' => 'dempuei la comen&ccedil;an&ccedil;a',
'onglet_repartition_lang' => 'Reparticion per lengas',
'onglet_repartition_rubrique' => 'Reparticion per rubricas',
'onglet_save_restaur_base' => 'Sauvagardar/restaurar la basa',
'onglet_vider_cache' => 'Vujar l\'escondedor',
'ortho_trop_de_fautes2' => 'Comen&ccedil;atz per corregir leis errors mai evidentas e tornatz assajar puei.',

// P
'pass_choix_pass' => 'Vougatz chausir v&ograve;stre mot de santa Clara nov&egrave;u:',
'pass_erreur' => 'Error',
'pass_erreur_acces_refuse' => '<b>Error :</b> pod&egrave;tz pus accedir a aqueu sit.',
'pass_erreur_code_inconnu' => '<b>Error :</b> aqueu c&ograve;de corresp&ograve;nd a ges de vesitaire que p&ograve;sca accedir a aqueu sit.',
'pass_erreur_non_enregistre' => '<b>Error:</b> l\'adrei&ccedil;a <tt>@email_oubli@</tt> es pas registrada sus aqueu sit.',
'pass_erreur_non_valide' => '<b>Error:</b> aquel e-mail <tt>@email_oubli@</tt> es pas valid!',
'pass_erreur_probleme_technique' => '<b>Error:</b> per am&ograve;r d\'un probl&egrave;ma tecnic, l\'e-mail se p&ograve;t pas mandar. ',
'pass_espace_prive_bla' => 'L\'espaci privat d\'aquest sit es dob&egrave;rt ai
  vesitaires que se son inscrichs. Un c&ograve;p registrat/ada,
  poiretz consultar leis articles en cors de redaccion,
  prepausar d\'articles nov&egrave;us e participar a totei lei forums.',
'pass_forum_bla' => 'Av&egrave;tz demandat d\'intervenir dins un forum
  reservat ai vesitaires registrats.',
'pass_indiquez_cidessous' => 'Marcatz &ccedil;ai sota l\'adrei&ccedil;a e-mail ont
 vos registreriatz lo c&ograve;p passat. 
   Recebretz un e-mail que vos bailar&agrave; lo biais de 
    tornar trobar v&ograve;stre acc&egrave;s.',
'pass_mail_passcookie' => '(aqu&ograve;\'s un messatge automatic)
Per tornar trobar v&ograve;stre acc&egrave;s au sit
@nom_site_spip@ (@adresse_site@)

Vougatz anar a l\'adrei&ccedil;a seguenta:

    @sendcookie@

Alora poiretz intrar un mot de santa Clara nov&egrave;u
e vos tornar connectar au sit.

',
'pass_mot_oublie' => 'Mot de santa Clara demembrat',
'pass_nouveau_enregistre' => 'V&ograve;stre mot de santa Clara nov&egrave;u es estat registrat.',
'pass_nouveau_pass' => 'Mot de santa Clara nov&egrave;u',
'pass_ok' => 'D\'ac&ograve;rdi',
'pass_oubli_mot' => 'Mot de santa Clara demembrat',
'pass_quitter_fenetre' => 'Quitar aquesta fen&egrave;stra ',
'pass_rappel_login' => 'Remembran&ccedil;a: v&ograve;stre identificant (login) es &laquo; @login@ &raquo;.',
'pass_recevoir_mail' => 'Recebretz un e-mail que vos explicar&agrave; coma tornar trobar v&ograve;stre acc&egrave;s au sit.',
'pass_retour_public' => 'Tornar au sit public',
'pass_rien_a_faire_ici' => 'Ren a faire aic&iacute;.',
'pass_vousinscrire' => 'S\'inscriure sus aquest sit',
'precedent' => 'precedent',
'previsualisation' => 'Previsualizacion',
'previsualiser' => 'Previsualizar',

// R
'retour' => 'Retour', # NEW

// S
'spip_conforme_dtd' => 'SPIP consid&egrave;re ce document comme conforme &agrave; son DOCTYPE :', # NEW
'squelette' => 'esqueleta',
'squelette_inclus_ligne' => 'esqueleta inclusa, linha',
'squelette_ligne' => 'esqueleta, linha',
'stats_visites_et_popularite' => '@visites@ vesitas; popularitat: @popularite@',
'suivant' => 'seguent',

// T
'taille_ko' => '@taille@&nbsp;Ko',
'taille_mo' => '@taille@&nbsp;Mo',
'taille_octets' => '@taille@&nbsp;octets',
'texte_actualite_site_1' => 'Quand vos seretz familharizat/ada amb l\'interf&agrave;cia, poiretz clicar sus &laquo;',
'texte_actualite_site_2' => 'Interf&agrave;cia completa',
'texte_actualite_site_3' => '" per dobrir mai de possibilitats.',
'texte_creation_automatique_vignette' => 'La creacion automatica de vinhetas de previsualizacion es activada sus aqueu sit. S\'installatz a partir d\'aqueu formulari d\'imatges au(ai) format(s) @gd_formats@, s\'acompanhar&agrave;n d\'una vinheta d\'una talha maximala de @taille_preview@ pix&egrave;ls.',
'texte_documents_associes' => 'Lei documents seguents s\'ass&ograve;cian a l\'article,
 mai s\'inserisson pas
 directament. Segon la compaginacion dau sit public,
 poir&agrave;n apar&eacute;isser sota forma de documents jonchs.',
'texte_erreur_mise_niveau_base' => 'Error de basa de donadas pendent la mesa a niv&egrave;u. L\'imatge <b>@fichier@</b> es pas passat (article @id_article@).
  Notatz ben aquela refer&eacute;ncia, tornatz assajar la mesa a
 niv&egrave;u, e verificatz puei que leis imatges aparegan
 encara dins leis articles.',
'texte_erreur_visiteur' => 'Vous avez tent&eacute; d\'acc&eacute;der &agrave; l\'espace priv&eacute; avec un login qui ne le permet pas.', # NEW
'texte_inc_auth_1' => 'Siatz identificat/ada coma
   <b>@auth_login@</b>, mai aqueu login exist&iacute;s pas o pus dins la basa.
  Assajatz de vos', # MODIF
'texte_inc_auth_2' => 'tornar connectar',
'texte_inc_auth_3' => ', apr&egrave;s qu\'auretz quitat eventualament, puei
  tornat lan&ccedil;ar v&ograve;stre navigador.',
'texte_inc_config' => 'Lei modificacions fachas dins aquestei paginas influ&eacute;ncian bravament lo
 foncionament de v&ograve;stre sit. Vos aconselham de pas i intervenir tant que siatz pas
 acostumat/ada au foncionament dau sist&egrave;ma SPIP. <br /><br /><b>
 En generau, se conselha f&ograve;rt
 de laissar la carga d\'aquestei paginas au webm&egrave;stre principau de v&ograve;stre sit.</b>',
'texte_inc_meta_1' => 'Lo sist&egrave;ma a rescontrat una error dins l\'escritura dau fichier <code>@fichier@</code>.Vougatz, coma administrator/tritz dau sit,',
'texte_inc_meta_2' => 'verificar lei drechs d\'escritura',
'texte_inc_meta_3' => 'dins lo repert&ograve;ri <code>@repertoire@</code>.',
'texte_statut_en_cours_redaction' => 'en cors de redaccion',
'texte_statut_poubelle' => 'au bordilhier',
'texte_statut_propose_evaluation' => 'prepausat per avaloracion',
'texte_statut_publie' => 'publicat en linha',
'texte_statut_refuse' => 'refusat',
'titre_ajouter_mot_cle' => 'APONDRE UN MOT CLAU:',
'titre_breve_proposee' => 'Br&egrave;va prepausada',
'titre_breve_publiee' => 'Br&egrave;va publicada',
'titre_breve_refusee' => 'Br&egrave;va refusada',
'titre_cadre_raccourcis' => 'ACORCHAS:',
'titre_changer_couleur_interface' => 'Cambiar la color de l\'interf&agrave;cia',
'titre_forum' => 'Forum',
'titre_image_admin_article' => 'Pod&egrave;tz administrar aquest article',
'titre_image_administrateur' => 'Administrator',
'titre_image_aide' => 'D\'ajuda subre aquel element',
'titre_image_auteur_supprime' => 'Autor suprimit',
'titre_image_redacteur' => 'Redactor sens acc&egrave;s',
'titre_image_redacteur_02' => 'Redactor',
'titre_image_visiteur' => 'Vesitaire',
'titre_joindre_document' => 'J&Oacute;NHER UN DOCUMENT',
'titre_liens_entrants' => 'Lei liames intrants',
'titre_mots_cles' => 'MOTS CLAU',
'titre_probleme_technique' => 'Atencion: un probl&egrave;ma tecnic (servidor SQL) empacha d\'accedir a aquela part dau sit. Grandmerc&eacute; de v&ograve;stra indulg&eacute;ncia.',
'titre_publier_document' => 'PUBLICAR UN DOCUMENT DINS AQUELA RUBRICA',
'titre_signatures_attente' => 'Signatures en attente de validation', # NEW
'titre_signatures_confirmees' => 'Signatures confirm&eacute;es', # NEW
'titre_statistiques' => 'Estadisticas dau sit',
'titre_titre_document' => 'T&iacute;tol dau document:',
'todo' => '&agrave; venir', # NEW
'trad_reference' => '(article de refer&eacute;ncia)',

// Z
'zbug_balise_b_aval' => '&nbsp;: balisa B en avau',
'zbug_balise_inexistante' => 'Balise @balise@ mal d&eacute;clar&eacute;e pour @from@', # NEW
'zbug_balise_sans_argument' => 'Argument manquant dans la balise @balise@', # NEW
'zbug_boucle' => 'bloca',
'zbug_boucle_recursive_undef' => 'bloca recursiva non definida', # MODIF
'zbug_calcul' => 'calcul', # NEW
'zbug_champ_hors_boucle' => 'Camp @champ@ f&ograve;ra bloca',
'zbug_champ_hors_motif' => 'Camp @champ@ en def&ograve;ra d\'una bloca de motiu @motif@', # MODIF
'zbug_code' => 'c&ograve;de',
'zbug_critere_inconnu' => 'crit&egrave;ri inconegut @critere@', # MODIF
'zbug_distant_interdit' => 'ext&egrave;rne enebit', # MODIF
'zbug_doublon_table_sans_cle_primaire' => 'Doublons sur une table sans clef primaire atomique', # NEW
'zbug_doublon_table_sans_index' => 'Doublons sur une table sans index', # NEW
'zbug_erreur_boucle_double' => 'BLOCA@id@: definicion dobla', # MODIF
'zbug_erreur_boucle_fermant' => 'BLOCA@id@: lo tag barrador manca', # MODIF
'zbug_erreur_boucle_syntaxe' => 'Sintaxi bloca incorr&egrave;cta', # MODIF
'zbug_erreur_compilation' => 'Erreur de compilation', # NEW
'zbug_erreur_execution_page' => 'error d\'execucion de la pagina', # MODIF
'zbug_erreur_filtre' => 'Error: filtre <b>&laquo; @filtre@ &raquo;</b> non definit', # MODIF
'zbug_erreur_meme_parent' => '{meme_parent} s\'aplica ren qu\'ai blocas (FORUMS) o (RUBRIQUES)', # MODIF
'zbug_erreur_squelette' => 'Error(s) dins l\'esqueleta',
'zbug_hors_compilation' => 'Hors Compilation', # NEW
'zbug_info_erreur_squelette' => 'Error subre lo sit',
'zbug_inversion_ordre_inexistant' => 'inversion d\'un &ograve;rdre inexistent', # MODIF
'zbug_pagination_sans_critere' => 'Balise #PAGINATION sans crit&egrave;re {pagination} ou employ&eacute; dans une boucle recursive', # NEW
'zbug_parametres_inclus_incorrects' => 'Param&egrave;tres d\'inclusion incorr&egrave;ctes', # MODIF
'zbug_profile' => 'Temps de calcul&nbsp;: @time@', # NEW
'zbug_resultat' => 'resultat',
'zbug_serveur_indefini' => 'servidor SQL indefinit', # MODIF
'zbug_statistiques' => 'Statistiques des requ&ecirc;tes SQL class&eacute;es par dur&eacute;e', # NEW
'zbug_table_inconnue' => 'Taula SQL &laquo;@table@&raquo; inconeguda',
'zxml_connus_attributs' => 'attributs connus', # NEW
'zxml_de' => 'de', # NEW
'zxml_inconnu_attribut' => 'attribut inconnu', # NEW
'zxml_inconnu_balise' => 'balise inconnue', # NEW
'zxml_inconnu_entite' => 'entit&eacute; inconnue', # NEW
'zxml_inconnu_id' => 'ID inconnu', # NEW
'zxml_mais_de' => 'mais de', # NEW
'zxml_non_conforme' => 'n\'est pas conforme au motif', # NEW
'zxml_non_fils' => 'n\'est pas un fils de', # NEW
'zxml_nonvide_balise' => 'balise non vide', # NEW
'zxml_obligatoire_attribut' => 'attribut obligatoire mais absent dans', # NEW
'zxml_succession_fils_incorrecte' => 'succession des fils incorrecte', # NEW
'zxml_survoler' => 'survoler pour voir les corrects', # NEW
'zxml_valeur_attribut' => 'valeur de l\'attribut', # NEW
'zxml_vide_balise' => 'balise vide', # NEW
'zxml_vu' => 'vu auparavant', # NE
);

?>
